/**
 * File: CompteEpargne.java
 * Created: 17 Oct 2012
 * Author: Jean-Philippe.Prost@univ-montp2.fr
 * Description:
 */

package opBancaires;

/**
 * @author <Jean-Philippe.Prost@LIRMM.fr> Creation 17 Oct 2012
 * 
 */
public class CompteEpargne extends CompteRemunereAbstract {

	// ********************* METHODES ********************************

	/*
	 * (non-Javadoc)
	 * 
	 * @see opBancaires.CompteAbstract#crediter(double)
	 */
	@Override
	public double crediter(double montant) throws OperationBancaireException {
		/*
		 * Le crédit d'un montant négatif est impossible :
		 */
		if (montant < 0) {
			this.getHistoriqueOperations().add(
					new Operation(this.getTitulaire(), this, StatutEnum.KO,
							NatureOperationEnum.CREDIT, montant));
			throw new OperationBancaireException(
					"Crédit d'un montant négatif impossible");
		}

		/*
		 * Le solde ne peut pas dépasser le plafond autorisé :
		 */
		if (this.getSolde() + montant > this.getPlafond()) {
			this.getHistoriqueOperations().add(
					new Operation(this.getTitulaire(), this, StatutEnum.KO,
							NatureOperationEnum.CREDIT, montant));
			throw new OperationBancaireException(
					"Dépassement du plafond autorisé");
		}

		/*
		 * Si tout va bien, alors création d'une opération, et crédit du compte
		 * :
		 */
		this.getHistoriqueOperations().add(
				new Operation(this.getTitulaire(), this, StatutEnum.OK,
						NatureOperationEnum.CREDIT, montant));
		this.setSolde(this.getSolde() + montant);
		return this.getSolde();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see opBancaires.CompteAbstract#crediter(double, opBancaires.Operation)
	 */
	@Override
	public double crediter(double montant, Operation op)
			throws OperationBancaireException {
		/*
		 * Le crédit d'un montant négatif est impossible :
		 */
		if (montant < 0) {
			op.initOperation(getTitulaire(), this, StatutEnum.KO,
					NatureOperationEnum.CREDIT, montant);
			this.getHistoriqueOperations().add(op);
			throw new OperationBancaireException(
					"Crédit d'un montant négatif impossible");
		}

		/*
		 * Le solde ne peut pas dépasser le plafond autorisé :
		 */
		if (this.getSolde() + montant > this.getPlafond()) {
			op.initOperation(getTitulaire(), this, StatutEnum.KO,
					NatureOperationEnum.CREDIT, montant);
			this.getHistoriqueOperations().add(op);
			throw new OperationBancaireException(
					"Dépassement du plafond autorisé");
		}

		/*
		 * Si tout va bien, alors création d'une opération, et crédit du compte
		 * :
		 */
		op.initOperation(this.getTitulaire(), this, StatutEnum.OK,
				NatureOperationEnum.CREDIT, montant);
		this.getHistoriqueOperations().add(op);
		this.setSolde(this.getSolde() + montant);
		return this.getSolde();
	}

	// ********************* CONSTRUCTEURS ********************************
	/**
	 * @param titulaire
	 */
	public CompteEpargne(Client titulaire, double plafond) {
		super(titulaire);
		this.setPlafond(plafond);
	}
}

// eof CompteEpargne.java
